Python Module Index — pySOT documentation

# Python Module Index

a | c | e | o | p | s | u

| a |
| `auxiliary_problems` | Find next points to sample
| c |
| `controller` | pySOT controllers
| e |
| `experimental_design` | Methods for generating an experimental design.
| o |
| `optimization_problems` | Optimization test problems for multi-modal and box-constrained global optimization
| p |
| `pySOT` |
| `pySOT.auxiliary_problems` |
| `pySOT.controller` |
| `pySOT.experimental_design` |
| `pySOT.optimization_problems` |
| `pySOT.strategy` |
| `pySOT.surrogate` |
| `pySOT.utils` |
| s |
| `strategy` | Surrogate optimization strategies
| `surrogate` | Surrogate models
| u |
| `utils` | Help functions for pySOT